﻿
/**		
 * 
 *	ColourPaletteDemo v1.00
 *	11/10/2008 17:53
 * 
 *	© JUSTIN WINDLE | soulwire ltd
 *	http://blog.soulwire.co.uk
 * 
 *  This class is licensed under Creative Commons Attribution 3.0 License:  
 *  http://creativecommons.org/licenses/by/3.0/
 * 
 *  You are free to utilise this class in any manner you see fit, but it is
 *  provided ‘as is’ without expressed or implied warranty. The author should
 *  be acknowledged and credited appropriately wherever this work is used.
 * 
 **/

package  
{
	import flash.display.Bitmap;
	import flash.display.BitmapData;
	import flash.display.Loader;
	import flash.display.Shape;
	import flash.display.Sprite;
	import fl.events.SliderEvent;
	import flash.events.Event;
	import flash.net.URLRequest;
	import uk.co.soulwire.display.colour.ColourUtils;

	public class ColourPaletteDemo extends Sprite
	{
	
		//___________________________________________________________		_____
		//————————————————————————————————————————————— CLASS MEMBERS		VALUE
		
		private var m_imageLoader:						Loader;
		private var m_inputImage:						BitmapData;
		private var m_paletteHolder:					Sprite;
		private var m_tolerance:						Number;
		private var m_colours:							Array;
		
		//___________________________________________________________
		//——————————————————————————————————————————————— CONSTRUCTOR
		
		public function ColourPaletteDemo() 
		{
			m_imageLoader = new Loader();
			m_imageLoader.contentLoaderInfo.addEventListener( Event.COMPLETE, onImageLoadComplete );
			m_imageLoader.load( new URLRequest( 'image.jpg' ) );
		}
		
		//___________________________________________________________
		//——————————————————————————————————————————————————— METHODS
		
		private function initialise():void
		{
			m_tolerance = 0.015;
			
			m_imageLoader.x = 10;
			m_imageLoader.y = 10;
			
			addChild( m_imageLoader );
			m_inputImage = Bitmap( m_imageLoader.contentLoaderInfo.content ).bitmapData;
			
			m_paletteHolder = new Sprite();
			m_paletteHolder.x = 370;
			m_paletteHolder.y = 10;
			addChild( m_paletteHolder );
			
			m_toleranceStep.addEventListener( SliderEvent.CHANGE, updateTolerance );
			m_toleranceStep.addEventListener( SliderEvent.THUMB_RELEASE, createColourPalette );
			
			createColourPalette();
		}
		
		//___________________________________________________________
		//———————————————————————————————————————————— EVENT HANDLERS
		
		private function onImageLoadComplete( event:Event ):void
		{
			initialise();
		}
		
		private function updateTolerance( event:SliderEvent ):void
		{
			m_tolerance = m_toleranceStep.value;
			m_toleranceValue.text = m_tolerance.toFixed(3);
		}
		
		private function createColourPalette( event:SliderEvent = null ):void
		{
			while ( m_paletteHolder.numChildren > 0 ) m_paletteHolder.removeChildAt(0);
			
			//_______________________________________________________
			//————————————————————————————— ColourUtils Example Usage
			
			m_colours = ColourUtils.colourPalette( m_inputImage, 32, m_tolerance );
			
			//_______________________________________________________
			
			trace( 'Colour palette created\n' );
			for each( var colour:uint in m_colours ) trace( '0x' + colour.toString(16) );
			
			var row:int = 0;
			var col:int = 0;
			var box:Shape;
			
			for (var i:int = 0; i < m_colours.length; i++) 
			{
				box = new Shape();
				
				box.x = col * 25;
				box.y = row * 25;
				
				box.graphics.beginFill( m_colours[i] );
				box.graphics.drawRect( 0, 0, 24, 24 );
				box.graphics.endFill();
				
				m_paletteHolder.addChild( box );
				
				if ( row++ == 7 )
				{
					row = 0;
					col++;
				}
			}
		}
		
	}
	
}
